package com.ruoyi.powerdistribution.controller;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.powerdistribution.domain.*;
import com.ruoyi.powerdistribution.domain.vo.ReportDayVO;
import com.ruoyi.powerdistribution.domain.vo.ReportDayWeek;
import com.ruoyi.powerdistribution.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;

@RestController
@AllArgsConstructor
@RequestMapping("/power/report")
//@Api(value = "powerReport", tags = "报表查询")
public class ReportController extends BaseController {

    @Autowired
    private IPdmReportAppointmentDayService pdmReportAppointmentDayService;
    @Autowired
    private IPdmReportIllegalDayService pdmReportIllegalDayService;
    @Autowired
    private IPdmReportPlanDayService pdmReportPlanDayService;
    @Autowired
    private IPdmReportPlanNextDayService pdmReportPlanNextDayService;
    @Autowired
    private IPdmReportAppointmentWeekService pdmReportAppointmentWeekService;
    @Autowired
    private IPdmReportIllegalWeekService pdmReportIllegalWeekService;
    @Autowired
    private IPdmReportPlanWeekService pdmReportPlanWeekService;
    @Autowired
    private IPdmReportPlanNextWeekService pdmReportPlanNextWeekService;

    /**
     * 日报查询
     */
    @ApiOperation(value = "日报查询", notes = "日报查询")
    @GetMapping("/day")
    public ReportDayVO day(String reportDate)
    {
        PdmReportIllegalDay pdmReportIllegalDay = new PdmReportIllegalDay();
        pdmReportIllegalDay.setReportDate(reportDate);
        List<PdmReportIllegalDay> illegalList = pdmReportIllegalDayService.selectPdmReportIllegalDayList(pdmReportIllegalDay);
        PdmReportAppointmentDay pdmReportAppointmentDay = new PdmReportAppointmentDay();
        pdmReportAppointmentDay.setReportDate(reportDate);
        List<PdmReportAppointmentDay> appointmentlist = pdmReportAppointmentDayService.selectPdmReportAppointmentDayList(pdmReportAppointmentDay);
        PdmReportPlanDay pdmReportPlanDay = new PdmReportPlanDay();
        pdmReportPlanDay.setReportDate(reportDate);
        List<PdmReportPlanDay> planlist = pdmReportPlanDayService.selectPdmReportPlanDayList(pdmReportPlanDay);
        PdmReportPlanNextDay nextDay = new PdmReportPlanNextDay();
        nextDay.setReportDate(DateUtils.getNextDateStr(reportDate,DateUtils.YYYYMMDD,1));
        List<PdmReportPlanNextDay> nextDayList = pdmReportPlanNextDayService.selectPdmReportPlanNextDayList(nextDay);

        ReportDayVO vo = new ReportDayVO();
        vo.setAppointmentList(appointmentlist);
        vo.setIllegalList(illegalList);
        vo.setPlanList(planlist);
        vo.setNextDayList(nextDayList);
        return vo;
    }

    @PostMapping("/dayExport")
    @ApiOperation(value = "日报导出")
    public void dayExport(HttpServletResponse response,String reportDate) throws IOException {
        InputStream fis = null;
        OutputStream ops = null;

        response.setContentType("application/vnd.ms-excel");
        response.setCharacterEncoding("utf-8");
        String fileName = java.util.UUID.randomUUID() + ".xlsx";
        response.setHeader("Content-disposition", "attachment;filename=" + fileName);
        String templateFileName = "excelTemplate/invoiceExport.xlsx";
        fis = Thread.currentThread().getContextClassLoader().getResourceAsStream(templateFileName);
        ops = response.getOutputStream();


        PdmReportIllegalDay pdmReportIllegalDay = new PdmReportIllegalDay();
        pdmReportIllegalDay.setReportDate(reportDate);
        List<PdmReportIllegalDay> illegalList = pdmReportIllegalDayService.selectPdmReportIllegalDayList(pdmReportIllegalDay);
        PdmReportAppointmentDay pdmReportAppointmentDay = new PdmReportAppointmentDay();
        pdmReportAppointmentDay.setReportDate(reportDate);
        List<PdmReportAppointmentDay> appointmentlist = pdmReportAppointmentDayService.selectPdmReportAppointmentDayList(pdmReportAppointmentDay);
        PdmReportPlanDay pdmReportPlanDay = new PdmReportPlanDay();
        pdmReportPlanDay.setReportDate(reportDate);
        List<PdmReportPlanDay> planlist = pdmReportPlanDayService.selectPdmReportPlanDayList(pdmReportPlanDay);
        PdmReportPlanNextDay nextDay = new PdmReportPlanNextDay();
        nextDay.setReportDate(DateUtils.getNextDateStr(reportDate,DateUtils.YYYYMMDD,1));
        List<PdmReportPlanNextDay> nextDayList = pdmReportPlanNextDayService.selectPdmReportPlanNextDayList(nextDay);





        //填充导出信息
        ExcelWriter excelWriter = EasyExcel.write(ops, AdsMatHyxtInvoiceD.class).withTemplate(fis).build();
        //WriteSheet writeSheet = EasyExcel.writerSheet().build();
        //FillConfig fillConfig = FillConfig.builder().forceNewRow(Boolean.TRUE).build();
        //excelWriter.fill(list, fillConfig, writeSheet);
        //excelWriter.finish();
    }

    /**
     * 周报查询
     */
    @ApiOperation(value = "周报查询", notes = "周报查询")
    @GetMapping("/week")
    public ReportDayWeek week(String startDate,String endDate)
    {
        PdmReportIllegalWeek pdmReportIllegal = new PdmReportIllegalWeek();
        pdmReportIllegal.setReportDate(startDate);
        pdmReportIllegal.setReportEndDate(endDate);
        List<PdmReportIllegalWeek> illegalList = pdmReportIllegalWeekService.selectPdmReportIllegalWeekList(pdmReportIllegal);
        PdmReportAppointmentWeek pdmReportAppointment = new PdmReportAppointmentWeek();
        pdmReportAppointment.setReportDate(startDate);
        pdmReportAppointment.setReportEndDate(endDate);
        List<PdmReportAppointmentWeek> appointmentlist = pdmReportAppointmentWeekService.selectPdmReportAppointmentWeekList(pdmReportAppointment);
        PdmReportPlanWeek pdmReportPlan = new PdmReportPlanWeek();
        pdmReportPlan.setReportDate(startDate);
        pdmReportPlan.setReportEndDate(endDate);
        List<PdmReportPlanWeek> planlist = pdmReportPlanWeekService.selectPdmReportPlanWeekList(pdmReportPlan);

        PdmReportPlanNextWeek next = new PdmReportPlanNextWeek();
        next.setReportDate(DateUtils.getNextMonday(startDate,DateUtils.YYYYMMDD));
        List<PdmReportPlanNextWeek> nextList = pdmReportPlanNextWeekService.selectPdmReportPlanNextWeekList(next);

        ReportDayWeek vo = new ReportDayWeek();
        vo.setAppointmentList(appointmentlist);
        vo.setIllegalList(illegalList);
        vo.setPlanList(planlist);
        vo.setNextList(nextList);
        return vo;
    }
}
